@@ -330,13 +330,13 @@ callback_restart (GtkWidget *widget, GdkEvent *event)
 		      _("Exit this game?"),
 		      NULL);
 
+      gtk_dialog_set_default_response (GTK_DIALOG (mb),
+		      GTK_RESPONSE_YES);
       response = gtk_dialog_run (GTK_DIALOG(mb));
       gtk_widget_destroy (mb);
 
       if (response == GTK_RESPONSE_YES)
-      {
 	      callback_restart_lose();
-      }
     }
   else
     callback_restart_really();
@@ -406,9 +406,9 @@ callback_new_with_seed_really (void)
 
   dialog = gtk_dialog_new_with_buttons (_("Seed"),
 		  GTK_WINDOW (main_window),
-		  0,
-		  GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+		  GTK_DIALOG_MODAL,
 		  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+		  GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 		  NULL);
 
   label = gtk_label_new (_("Seed value:"));
@@ -419,7 +419,9 @@ callback_new_with_seed_really (void)
   entry = gtk_entry_new ();
   gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(dialog)->vbox), entry);
   gtk_widget_show (entry);
+  gtk_widget_grab_focus (entry);
 
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
   response = gtk_dialog_run (GTK_DIALOG(dialog));
   gtk_widget_hide (dialog);
 
@@ -460,6 +462,8 @@ callback_new_with_seed (GtkWidget *widget, GdkEvent *event)
 		      _("Exit this game?"),
 		      NULL);
 
+      gtk_dialog_set_default_response (GTK_DIALOG (mb),
+		      GTK_RESPONSE_YES);
       response = gtk_dialog_run (GTK_DIALOG(mb));
       gtk_widget_destroy(mb);
 
@@ -525,6 +529,8 @@ callback_new (GtkWidget *widget, GdkEvent *event)
 		      _("Exit this game?"),
 		      NULL);
 
+      gtk_dialog_set_default_response (GTK_DIALOG (mb),
+		      GTK_RESPONSE_YES);
       response = gtk_dialog_run (GTK_DIALOG(mb));
       gtk_widget_destroy(mb);
 
@@ -619,6 +625,8 @@ callback_exit (GtkWidget *widget, GdkEvent *event)
 		      _("Exit this game?"),
 		      NULL);
 
+      gtk_dialog_set_default_response (GTK_DIALOG (mb),
+		      GTK_RESPONSE_YES);
       response = gtk_dialog_run (GTK_DIALOG(mb));
       gtk_widget_destroy (mb);
 
@@ -641,6 +649,12 @@ callback_about (GtkWidget *widget, GdkEvent *event)
     NULL
   };
 
+  const gchar *documenters[] = {
+	  NULL
+  };
+
+  const gchar *translator_credits = _("translator_credits");
+
 #ifndef ELEMENTS  
 #define ELEMENTS(x) (sizeof(x) / sizeof(x[0]))
 #endif /* ELEMENTS */
@@ -665,8 +679,8 @@ callback_about (GtkWidget *widget, GdkEvent *event)
 			   "(C) 1998 Free Software Foundation, Inc.",
 			   _("Reimplement the popular solitaire card game."),
 			   (const char **)authors,
-			   NULL,
-			   NULL,
+			   (const char **)documenters,
+			   strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			   pixbuf);
   gtk_widget_show (about);
 }
@@ -685,6 +699,7 @@ inform_invalid_move (void)
 
   gtk_widget_show (mb);
   gtk_dialog_run (GTK_DIALOG(mb));
+  gtk_widget_destroy (mb);
 }
 
 static void
