@@ -84,7 +84,7 @@ static GnomeUIInfo game_menu[] = {
 	GNOMEUIINFO_MENU_SCORES_ITEM (show_scores_cb, NULL),
 	GNOMEUIINFO_MENU_END_GAME_ITEM (end_game_cb, (gpointer) 2),
 	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_MENU_EXIT_ITEM (quit_cb, NULL),
+	GNOMEUIINFO_MENU_QUIT_ITEM (quit_cb, NULL),
 	GNOMEUIINFO_END
 };
 
@@ -174,6 +174,7 @@ static void quit_cb (GtkWidget *widget, gpointer data)
 static void about_cb (GtkWidget *widget, gpointer data)
 {
 	static GtkWidget *about;
+	GdkPixbuf *pixbuf = NULL;
 
 	const gchar *authors[] = {"Sean MacIsaac", "Ian Peters", NULL};
 	gchar *documenters[] = {
@@ -188,6 +189,19 @@ static void about_cb (GtkWidget *widget, gpointer data)
 		return;
 	}
 
+	{
+		char *filename = NULL;
+
+		filename = gnome_program_locate_file (NULL,
+				GNOME_FILE_DOMAIN_PIXMAP, "gnome-nibbles.png",
+				TRUE, NULL);
+		if (filename != NULL)
+		{
+			pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+			g_free (filename);
+		}
+	}
+
 	about = gnome_about_new (_("Gnibbles"), VERSION,
 			"(C) 1999 Sean MacIsaac and Ian Peters",
 			_("Send comments and bug reports to: "
@@ -195,7 +209,7 @@ static void about_cb (GtkWidget *widget, gpointer data)
 			(const char **)authors,
 			(const char **)documenters,
 			strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-			NULL);
+			pixbuf);
 	g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK
 			(gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
@@ -626,7 +640,7 @@ int main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 	
-	gnome_program_init ("Gnibbles", VERSION, LIBGNOMEUI_MODULE,
+	gnome_program_init ("gnibbles", VERSION, LIBGNOMEUI_MODULE,
 			    argc, argv,
 			    GNOME_PARAM_POPT_TABLE, NULL,
 			    GNOME_PARAM_APP_DATADIR, REAL_DATADIR,
